@@ -1033,8 +1033,10 @@ static int run_watches (void)
 	    n = max (n, watch_table[i]->fd);
 	}
     }
+#if 0	/* Norbert Nemec <nobbi@cheerful.com> */
     if (!n)
 	return 0;
+#endif	/* Norbert Nemec <nobbi@cheerful.com> */
     r = select (n + 1, &reading, &writing, &error, 0);
     if (r <= 0)
 	return 0;
