@@ -1409,7 +1409,7 @@ void edit_indent_left_right_paragraph (WEdit * edit)
     CDisable ("*");
     p =
 	CDrawText ("status_prompt", edit->widget->parentid, CXof (w), CYof (w), "%s",
-		   " <---  ---> ");
+		   _(" <---  ---> (this eats your undo stack) "));
     width = CWidthOf (p);
     i = CDrawTextInput ("status_input", edit->widget->parentid, CXof (w) + width, CYof (w),
 			CWidthOf (edit->widget) - width, AUTO_HEIGHT, 1, "");
