@@ -777,7 +777,7 @@ void edit_render (WEdit * edit, int page, int row_start, int col_start, int row_
 	);
     edit_set_background_colors (
 				 color_palette (option_editor_bg_normal),
-			       color_palette (option_editor_bg_abnormal),
+			       color_palette ((option_editor_bg_normal == option_editor_bg_abnormal) ? (option_editor_bg_normal ? 0 : 1) : option_editor_bg_abnormal),
 				 color_palette (option_editor_bg_marked),
 			color_palette (option_editor_bg_marked_abnormal),
 			     color_palette (option_editor_bg_highlighted)
